ValueType

Enum ValueType 

pub enum ValueType {
Show 23 variants Bool, S8, U8, S16, U16, S32, U32, S64, U64, F32, F64, Char, String, List(ListType), Record(RecordType), Tuple(TupleType), Variant(VariantType), Enum(EnumType), Option(OptionType), Result(ResultType), Flags(FlagsType), Own(ResourceType), Borrow(ResourceType),
}
Represents a component model interface type.

Variants



Bool

The boolean type.



S8

The eight-bit signed integer type.



U8

The eight-bit unsigned integer type.



S16

The 16-bit signed integer type.



U16

The 16-bit unsigned integer type.



S32

The 32-bit signed integer type.



U32

The 32-bit unsigned integer type.



S64

The 64-bit signed integer type.



U64

The 64-bit unsigned integer type.



F32

The 32-bit floating point number type.



F64

The 64-bit floating point number type.



Char

The UTF-8 character type.



String

The string type.



List(ListType)

The homogenous list of elements type.



Record(RecordType)

The record with heterogenous fields type.



Tuple(TupleType)

The tuple with heterogenous fields type.



Variant(VariantType)

The variant which may be one of multiple types or cases type.



Enum(EnumType)

The enum which may be one of multiple cases type.



Option(OptionType)

The type which may or may not have an underlying value type.



Result(ResultType)

The type that indicates success or failure type.



Flags(FlagsType)

The set of boolean values type.



Own(ResourceType)

The owned resource handle type.



Borrow(ResourceType)

The borrowed resource handle type.