pub trait ComponentList: 'static + Sized {
const LEN: usize;
// Required methods
fn into_tys(types: &mut [ValueType]);
fn into_values(self, values: &mut [Value]) -> Result<()>;
fn from_values(values: &[Value]) -> Result<Self>;
}Expand description
Marks a list of components that can be passed as parameters and results.
Required Associated Constants
Required Methods
Sourcefn into_tys(types: &mut [ValueType])
fn into_tys(types: &mut [ValueType])
Stores the types of this list into the given slice. Panics if the slice is not big enough.
Sourcefn into_values(self, values: &mut [Value]) -> Result<()>
fn into_values(self, values: &mut [Value]) -> Result<()>
Attempts to convert this component list into values, storing them in the provided slice.
Sourcefn from_values(values: &[Value]) -> Result<Self>
fn from_values(values: &[Value]) -> Result<Self>
Attempts to convert a list of values into a component list of this type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".